@@ -16,8 +16,8 @@ You should have received a copy of the GNU General Public License
 along with this program; see the file COPYING.  If not, write to
 the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-   The author may be reached (Email) at the address marc@david.saclay.cea.fr,
-   or (US/French mail) as Tristan Gingold 
+ The author may be reached (Email) at the address gingold@amoco.saclay.cea.fr,
+ or (US/French mail) as Tristan Gingold 
    			  8 rue Parmentier
    			  F91120 PALAISEAU
    			  FRANCE
@@ -36,9 +36,6 @@ the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 /* size of red zones */
 extern unsigned int be_red_zone;	/* bytes, but must long */
 extern unsigned int af_red_zone;
-
-/* magic number in magic (Yes, I'm french :-) */
-#define RED_ZONE_MAGIC 0xcafe0cfc
 #endif /* CHKR_GARBAGE */
 
 #ifdef CHKR_SAVESTACK
@@ -117,4 +114,6 @@ void *sys_malloc(size_t real_size);
 void sys_free(void * ptr);
 void *sys_realloc (void * ptr, size_t size);
 
+/* How many fd are used by checker */
+#define CHKR_OPEN 3
 #endif /* checker.h  */
