@@ -14,3 +14,9 @@ E_MEMACCERR	"Memory access error"
 E_IE_BRIGHT	"Internal error: bad right while checking"
 E_IE_INSTUK	"Internal error: instruction unknown"
 E_IE_BSYSCALL	"Internal error: can't check this syscall"
+E_BAD_FD	"Try to use a fd reserved by Checker"
+E_BAD_SFD	"The system has returned a fd reserved by Checker"
+E_BAD_SBRK	"Try to free memory through sbrk/brk"
+E_NOT_RECURS	"Checker V0.5 is not recursive!!"
+E_OUT_OF_SMEM	"Out of system memory!!"
+E_OUT_OF_MEM	"Warning: virtual memory exceeded."
