@@ -1,9 +1,10 @@
 $header "const char *chkr_message[]"
 $declare "const char *chkr_message[];"
-$format "chkr_message[%d]"
+$hformat "chkr_message[%d]"
 
 ######## for parse-args.c
 M_UNKNOWN_OP		"Checker doesn't know this option: %s\n"
+M_UNKNOWN_DISABLE	"Checker doesn't know this 'disable' option: %s\n"
 M_PRGNAME_NOT_FOUND	"Can't find program name.\n"
 M_ARGV0_IS		"My name (given by argv[0]) is %s\n"
 M_STOPPING_MYSELF	"Stop before main(). To cont, try 'fg' or 'kill -%d %d'\n"
@@ -13,7 +14,7 @@ M_IOCTL_UNIMPLEMENT	"Sorry, this ioctl is not implemented.\n"
 M_FCNTL_UNIMPLEMENT	"Sorry, this fcntl is not implemented.\n"
 M_SYSCALL_UNIMPLEM	"Sorry, this syscall is not implemented.\n"
 M_IPC_UNIMPLEMENT	"Sorry, ipc syscalls not implemented.\n"
-M_SEND_DESCRIPTION	"Please, send a description of it to the author.\n"
+M_SEND_DESCRIPTION	"Please, send a description of it to the author of Checker.\n"
 ######### for symtab.c
 M_STACK_FRAMES_ARE	"Stack frames are:\n"
 M_CANT_FIND_MAIN	"Can't find main() frame, you lose!\n"
@@ -21,7 +22,9 @@ M_CANT_F_GOOD_INFO	"Can't find good information in the binary file.\n"
 M_PC___IN___AT_		"\tpc=0x%08x in %s() at %s:%d\n"
 M_UNKNOWN		"Unknown"
 M_BAD_STR		"<bad string table index>"
-######### for checker.c
+######### for utils.c
+M_UNKNOWN_MALLOC0	"This argument %s for the '--malloc0=' option is unknown.\n"
+M_MALLOC0_WARNING	"Warning: you are using %s with a size of 0\n"
 M_C_FB_OR_LB_BAD	"_firstblock or _lastblock is bad\n"
 M_C_NO_BLOCKS		"No blocks. Sorry.\n"
 M_C_FBLOCK_BAD		"_firstblock is bad.\n"
@@ -82,14 +85,17 @@ M_STACK_SEGMENT		"stack"
 M_BLOCK_ALLO_FRM	"The block was allocated from:\n"
 M_KNOW_STACK_LIM	"known stack limit= 0x%p\n"
 M_STACK_BITMAPED	"stack bitmaped 0x%p\n"
+M_INSIDE_UNKNOWN	"not inside the heap(???)\n"
 M_INSIDE_FBLOCK		"inside a free block.\n"
 M_BLOCK_ID		"The block is %u bytes length and starts at 0x%x\n"
 M_BEFORE_BLOCK		"%d bytes before the begin of the block\n"
 M_INSIDE_BLOCK		"%d bytes after the begin of the block\n"
 M_AFTER_BLOCK		"%d bytes after the end of the block\n"
 M_N_FREE_CALLED		"free() was called %d time(s) since this block was freed by:\n"
-M_MEM_ACCESS_ERR	"Memory access error\n"
+M_MEM_ACCESS_ERR	"Memory access error: %s\n"
 M_ACC_ERR_WHERE		"When %s %d byte(s) at address 0x%p, inside the %s.\n"
 M_USE_NULL_PTR		"You probably use a NULL pointer.\n"
 M_PROD_SEG_FAULT	"THIS SHOULD PRODUCE A SEGMENTATION FAULT.\n"
 M_CANT_MODIFY_IT	"You may not modify it.\n"
+############# for vprintf.c
+M_FROM_CHECKER		"From Checker: (pid:%d)\n"
