@@ -6,7 +6,7 @@
 
 extern void * ___brk_addr;
 
-void *sbrk(ptrdiff_t increment)
+void *chkr_sbrk(ptrdiff_t increment)
 {
 	void * tmp = ___brk_addr+increment;
 #if defined(__PIC__) || defined (__pic__)
