@@ -70,8 +70,9 @@ extern int nosymtab;
    Not really portable ...
  */
 /*#define GOODSYM(x) ( ((x)& ~N_EXT) == N_TEXT || ((x)& ~0x20) == 0x44 )*/
-#define GOODSYM(x) ( (x) == N_SO || (x) == N_SOL || (x) == N_SLINE || (x) == N_FUN)
+#define GOODSYM(x) ((x) == N_SO || (x) == N_SOL || (x) == N_SLINE || (x) == N_FUN)
 
+#if OLD_SHOW_ADDR
 /* You can use any demangler. But, It must not use malloc ... */
 static char *simple_demangler(char *name);
 extern char *cplus_demangle (char *type); /* from binutils */
@@ -80,14 +81,18 @@ extern char *cplus_demangle (char *type); /* from binutils */
    simple for C name: just remove the '_'
    rather difficult for C++ */
 char *(*demangler)(char *name) = simple_demangler;
+#endif
 
+#if OLD_SHOW_ADDR
 /* Compare two symbols.
    It is necessary to sort. */
-static int symcomp(const __ptr_t ptr1, const __ptr_t ptr2)
+static int
+symcomp(const __ptr_t ptr1, const __ptr_t ptr2)
 {
   return ( (struct nlist*)ptr1 )->n_value -
          ( (struct nlist*)ptr2 )->n_value;
 }
+#endif /* 0 */
 
 /* function called at exit, to remove the temp file */
 void
@@ -177,7 +182,7 @@ prepare_symtab_file(void)
 #ifdef CHKR_USE_BITMAP 
    if (N_MAGIC(header) == OMAGIC)
      is_text_writable = 1;	/* can write in the text segment */
-#endif         
+#endif /* CHKR_USE_BITMAP */         
        
    /* jump to the symbol table */
    if (lseek(fd, N_SYMOFF(header), 0) < 0)
@@ -230,27 +235,27 @@ prepare_symtab_file(void)
              /* copy the string */
              strcpy(str, &string_table[ sym1->n_un.n_strx 
            		- sizeof(string_table_size) ]);
+#if OLD_SHOW_ADDR
      	     /* Forget some unuseful symbols */
              if (sym1->n_type == N_TEXT
                  && !( strcmp(str, "gcc2_compiled.") && 
          	       strcmp(str, "___gnu_compiled_c") ) )
                continue;
-#if 0
              /* forget pathes given as names */
              if (sym1->n_type == 0x64 && strlen(str) > 0 && 
            		str[strlen(str)-1] == '/' )
                continue;
-#endif
+#endif /* 0 */
              sym1->n_un.n_strx = str_index;
              str_index += strlen(&string_table1[str_index]) + 1;
            } 
          sym1++;
        }
    nsymbols = sym1 - symbols;
-#if 0
+#if OLD_SHOW_ADDR
    /* sort the symbols table, according to the value */
    qsort(symbols, nsymbols, sizeof(symbols[0]), symcomp);
-#endif
+#endif /* 0 */
      
    chkr_close(fd);		/* all is right */
  
@@ -281,7 +286,7 @@ prepare_symtab_file(void)
 #if 0         
        /* This file will be removed at the end */
        atexit(chkr_remove_symtabfile);
-#endif         
+#endif /* 0 */         
      }
    else
      goto error;
@@ -377,7 +382,8 @@ chkr_unload_symtab(void)
      symtab_available--;
    }
 }
-  
+
+#if OLD_SHOW_ADDR  
 /* Load the symbol table and call func to use the symbol table.
    The symbol table in memory keep only 'useful' symbols, and it is sorted.
    So, to be faster, the symtab is written to a temp file, and all next 
@@ -394,9 +400,11 @@ chkr_use_symtab(void (*func)(int status))
  chkr_unload_symtab();
 }
 
+/* #if OLD_SHOW_ADDR */
 /* Test if f is a filename with an .o extention
    This function recognize *.o file. */
-static int is_obj_filename(char *f)
+static int 
+is_obj_filename(char *f)
 {
   while (*f)
     f++;
@@ -406,7 +414,6 @@ static int is_obj_filename(char *f)
     return 0;
 }
 
-#if 0
 /* Show all the information about an address (of a function).  */
 void
 chkr_show_addr(__ptr_t *ptr)
@@ -469,7 +476,7 @@ chkr_show_addr(__ptr_t *ptr)
     	file_name ? file_name->n_un.n_name : M_UNKNOWN, /* file name */
     	line ? (int)line->n_desc : 0);
 }
-#endif
+#endif /* 0 */
 
 /* NOTE: This come from bfd/aoutx.h */
 void
@@ -484,13 +491,14 @@ chkr_show_addr(__ptr_t *ptr)
   char *main_file_name = NULL;
   char *current_file_name = NULL;
   char *line_file_name = NULL; /* Value of current_file_name at line number. */
-  ulong high_line_vma = ~0;
+  ulong low_line_vma = 0;
   ulong low_func_vma = 0;
   struct nlist *func = 0;
   struct nlist *p;
   
   if (symtab_available == 0)
     return;
+  filename_buffer[0] = '\0';
   for (p = symbols; p < &symbols[nsymbols]; p++)
     {
     next:
@@ -512,13 +520,12 @@ chkr_show_addr(__ptr_t *ptr)
       case N_SOL:
 	current_file_name = p->n_un.n_name;
 	break;
-
       case N_SLINE:
 	/* We'll keep this if it resolves nearer than the one we have already */
-	if (p->n_value >= (ulong)*ptr && p->n_value < high_line_vma)
+	if (p->n_value >= low_line_vma && p->n_value <= (ulong)*ptr)
 	  {
 	    line = p->n_desc;
-	    high_line_vma = p->n_value;
+	    low_line_vma = p->n_value;
 	    line_file_name = current_file_name;
 	  }
 	break;
@@ -530,27 +537,25 @@ chkr_show_addr(__ptr_t *ptr)
 	      low_func_vma = p->n_value;
 	      func = p;
 	    }
-	  if (line && func)
-	    {
-	      char *function = func->n_un.n_name;
-	      char *p;
-	      strncpy(buffer, function, sizeof(buffer)-1);
-	      buffer[sizeof(buffer)-1] = 0;
-	      /* Have to remove : stuff */
-	      p = strchr(buffer, ':');
-	      if (p != NULL) 
-	        *p = '\0';
-	      functionname = buffer;
-	      goto done;
-	    }
 	}
 	break;
       }
   }
 
- done:
   if (line)
     main_file_name = line_file_name;
+  if (func)
+  {
+      char *function = func->n_un.n_name;
+      char *p;
+      strncpy(buffer, function, sizeof(buffer)-1);
+      buffer[sizeof(buffer)-1] = 0;
+      /* Have to remove : stuff */
+      p = strchr(buffer, ':');
+      if (p != NULL) 
+	  *p = '\0';
+      functionname = buffer;
+  }
 #if 0
   if (main_file_name)
     {
@@ -562,20 +567,20 @@ chkr_show_addr(__ptr_t *ptr)
           strncat(filename_buffer, main_file_name, 50);
         }
     }
-#else
+#else /* !0 */
   strncpy(filename_buffer, main_file_name, 150);
-#endif
+#endif /* !0 */
 
   chkr_printf(M_PC___IN___AT_,
   	*ptr, /* pc or ip */
   	functionname ? functionname : M_UNKNOWN, /* function name */ 
-    	filename_buffer ? filename_buffer : M_UNKNOWN, /* file name */
+    	filename_buffer[0] ? filename_buffer : M_UNKNOWN, /* file name */
     	line);
 }
 
-
 /* Show all the symbol table.  */
-void chkr_dump_symtab(void)
+void
+chkr_dump_symtab(void)
 {
   int i;
   struct nlist *sp;
@@ -597,12 +602,15 @@ void chkr_dump_symtab(void)
     }
 }
 
+#if OLD_SHOW_ADDR
 /* Very simple demangler for C name */
-static char *simple_demangler(char *name)
+static char
+*simple_demangler(char *name)
 {
  if(name[0] == '_')
    return &name[1];
  else
    return name;
 }
-#endif /* CHKR_SAVESTACK */
\ No newline at end of file
+#endif
+#endif /* CHKR_SAVESTACK */
