@@ -1,3 +1,4 @@
+
 /* morecore.c - C library support routine for UNIX.
    Copyright (c) 1989, 1993  Michael J. Haertel
    You may redistribute this library under the terms of the
@@ -12,40 +13,22 @@
 #include <stddef.h>
 #include "malloc.h"
 
-extern void *sbrk(int);
+extern void *sbrk (int);
 
 /* Note that morecore has to take a signed argument so
    that negative values can return memory to the system. */
 void *
-morecore(int size)
+morecore (int size)
 {
-    void *result;
+  void *result;
 
-    result = sbrk(size);
-    if (result == (void *) -1)
-	return NULL;
-    return result;
+  result = sbrk (size);
+  if (result == (void *) -1)
+    {
+      chkr_errno = E_OUT_OF_MEM;
+      chkr_perror ();
+      return NULL;
+    }
+  return result;
 }
 
-#ifdef WITHDUMMY
-void chkr_initialize()
-{
-}
-
-void chkr_save_stack(__ptr_t *ptr, int forget, int num)
-{
-}
-
-void chkr_set_right(__ptr_t ptr, int len, int right)
-{
-}
-
-void chkr_show_frames()
-{
-}
-
-void chkr_do_end()
-{
- exit(1);
-}
-#endif
\ No newline at end of file
