@@ -1,4 +1,4 @@
-/* Memory access checker.
+/* Parse arguments for Checker
    Copyright 1993 Tristan Gingold
 		  Written October 1993 by Tristan Gingold
 
@@ -16,8 +16,8 @@ You should have received a copy of the GNU General Public License
 along with this program; see the file COPYING.  If not, write to
 the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-   The author may be reached (Email) at the address marc@david.saclay.cea.fr,
-   or (US/French mail) as Tristan Gingold 
+ The author may be reached (Email) at the address gingold@amoco.saclay.cea.fr,
+ or (US/French mail) as Tristan Gingold 
    			  8 rue Parmentier
    			  F91120 PALAISEAU
    			  FRANCE
@@ -26,10 +26,10 @@ the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #include <fcntl.h>
 #include <sys/param.h>
 #include <signal.h>
+#include <limits.h>
 #include "checker.h"
 #include "errlist.h"
 #include "message.h"
-#include "dmstrings.h"
 
 #ifndef DEFAULT_HOME
 #define DEFAULT_HOME "/tmp"
@@ -45,6 +45,9 @@ static dev_t st_dev;	/* just for checking */
 static ino_t st_ino;
 static char chkr_out_file[MAXPATHLEN] = "/dev/tty";
 unsigned int null_pointer_zone = 0x04;
+extern void *___chkr_ld_opts__;	/* just for its address */
+int chkr_ld_options = (int)&___chkr_ld_opts__;
+static int do_detector_at_end;	/* True if must detect garbage at the end */
 #ifdef CHKR_SAVESTACK
 int nosymtab;
 #endif
@@ -67,54 +70,18 @@ static int atod(const char *c);
 static int ctod(const char c);
 static void store_output_spec(void);
 extern void save_signals(void);
-
+extern int parse_disable(const char *str);
+extern void set_malloc0_behavior(const char *opt);
+extern void __chkr_garbage_detector(void);
 struct mem_range (*disable)[];
 int disable_cur;
 int disable_max;
 
-static char* init_message[]=
-{
-  M_COPY_M1,
-  M_COPY_M2,
-  M_COPY_M3,
-  M_COPY_M4,
-  M_COPY_M5,
-  M_COPY_M6,
-  M_COPY_M7,
-  "\n",
-  NULL
-};
-
-static char* help_message[]=
-{ M_HELP_M1,
-  M_HELP_M2,
-  M_HELP_M3,
-  M_HELP_M4,
-  M_HELP_M5
-  M_HELP_M6,
-#ifdef CHKR_SAVESTACK  
-  M_HELP_M7,
-#endif
-  M_HELP_M8,
-  M_HELP_M9,
-#ifdef CHKR_PROFILE
-  M_HELP_M10,
-#endif    
-  M_HELP_M11,
-  M_HELP_M12,
-  "\n",
-  NULL
-};
-  
-static char* abort_message[]=
-{
-  M_ABORT_M1,
-  NULL
-};
+#include "parse-args.mes"
    
-/* __chkr_init_chkr is called before main() */
+/* ___chkr_init_chkr is called before main() */
 void
-__chkr_init_chkr(int argc, char *argv[], char *argp[])
+___chkr_init_chkr(int argc, char *argv[], char *argp[])
 {
  char *args;
  char *out;
@@ -136,6 +103,9 @@ __chkr_init_chkr(int argc, char *argv[], char *argp[])
  else
    already_init = 1;
    
+ dup2(chkr_out, OPEN_MAX - CHKR_OPEN);
+ chkr_out = OPEN_MAX - CHKR_OPEN;
+   
  chkr_prog_path = chkr_find_executable(argv[0]);
  progname = argv[0];
  
@@ -162,7 +132,10 @@ __chkr_init_chkr(int argc, char *argv[], char *argp[])
      
  if (!silent)
    print_message(init_message);
-    
+
+ if (!silent && (chkr_ld_options & 1))
+   print_message(link_with_other_message);
+       
  chkr_errno = E_UNKNOWN;
  /* some trivial checks. ??_red_zone must be a multiple of 4 */
  if ( be_red_zone % sizeof(void*) || af_red_zone % sizeof(void*))
@@ -277,7 +250,9 @@ struct Opt options[]={
 {1, 'N', "NULLzone", 1},	/* set the size of the NULL zone */
 {1, 'd', "disable", 1},		/* disable an address */
 {1, 'S', "stop", 0},		/* stop before main, use SIGCONT to restart */
-{0, 0, "",0}};
+{1, 'D', "detector", 1},	/* detector */
+{1, 'm', "malloc0", 1},		/* malloc(0) behavior */
+{0, 0, "", 0}};
 
 char *optarg;
 static int
@@ -293,8 +268,8 @@ getopt(char *option)
        {
          if(tmp->arg && strncmp(option+2, tmp->long_opt, strlen(tmp->long_opt))==0)
            {
-              optarg = option + 3 + strlen(tmp->long_opt);
-              return tmp->short_opt;
+             optarg = option + 3 + strlen(tmp->long_opt);
+             return tmp->short_opt;
            }
          else
            if(strcmp(option + 2, tmp->long_opt)==0)
@@ -347,7 +322,10 @@ parse_opt(char *option)
        if (chkr_out == 0)
          chkr_out = 2;
        else
-           strcpy(chkr_out_file, optarg);
+         strcpy(chkr_out_file, optarg);
+       dup2(chkr_out, OPEN_MAX - CHKR_OPEN);
+       close(chkr_out);
+       chkr_out = OPEN_MAX - CHKR_OPEN;
        break;
      case 'p':  /* profile */
 #ifdef CHKR_PROFILE
@@ -364,6 +342,12 @@ parse_opt(char *option)
          int a;
          
          strcpy(arg, optarg);
+         if (arg[0] >= 'a' && arg[0] <= 'z')
+           if(!parse_disable(arg))
+             {
+               chkr_printf(M_UNKNOWN_DISABLE, optarg);
+               break;
+             }
          c = strchr(arg, '-');
          if (c == (char*)0)
            {
@@ -385,6 +369,13 @@ parse_opt(char *option)
      case 'S':  /* stop */
        stop = 1;
        break;
+     case 'D': /* detector */
+       if (strcmp(optarg, "end") == 0)
+         do_detector_at_end = 1;
+       break;
+     case 'm': /* malloc(0) behavior */
+       set_malloc0_behavior(optarg);
+       break;
      default:
        chkr_printf(M_UNKNOWN_OP, option);
    }
@@ -471,10 +462,10 @@ read_config_file(char *file)
 static void
 print_message(char **message)
 {
- while(*message != (char*)0)
+ while(*message != (char*)0 && **message != 0)
    {
-      write(chkr_out, *message, strlen(*message));
-      message++;
+     write(chkr_out, *message, strlen(*message));
+     message++;
    }
 }
 
@@ -510,12 +501,12 @@ atod(const char *c)
     }
   while(*c != '\0')
     {
-       digit = ctod(*c);
-       c++;
-       if (digit == -1 || digit >= base)
-         break;
-       val *= base;
-       val += digit;
+      digit = ctod(*c);
+      c++;
+      if (digit == -1 || digit >= base)
+        break;
+      val *= base;
+      val += digit;
     }
   return val;
 }
@@ -551,6 +542,8 @@ add_disable(uint first, uint last)
 void
 chkr_do_end()
 {
+ if (do_detector_at_end)
+   __chkr_garbage_detector();
  chkr_remove_symtabfile();
 #ifdef CHKR_PROFILE
  if (profile)
@@ -589,6 +582,9 @@ check_output_spec()
       chkr_out = open(chkr_out_file,O_APPEND|O_WRONLY);
       if (chkr_out == -1)
         chkr_out = 2;
+      dup2(chkr_out, OPEN_MAX - CHKR_OPEN);
+      close(chkr_out);
+      chkr_out = OPEN_MAX - CHKR_OPEN;
       store_output_spec();
     }
    errno = errno_ori;
