@@ -264,11 +264,11 @@ static const template i386_optab[] = {
 
 /* control transfer instructions */
 #define CALL_PC_RELATIVE 0xe8
-{"call", 1, 0xe8, _, JumpDword, { Disp32, 0, 0} C(StackOp)},
-{"call", 1, 0xff, 2, Modrm, { Reg|Mem|JumpAbsolute, 0, 0} C(ReadMem)},
+{"call", 1, 0xe8, _, JumpDword, { Disp32, 0, 0} C(CallOp)},
+{"call", 1, 0xff, 2, Modrm, { Reg|Mem|JumpAbsolute, 0, 0} C(ReadMem|CallOp)},
 #define CALL_FAR_IMMEDIATE 0x9a
-{"lcall", 2, 0x9a, _, JumpInterSegment, { Imm16, Abs32|Imm32, 0} C(StackOp)},
-{"lcall", 1, 0xff, 3, Modrm, { Mem, 0, 0} C(ReadMem)},
+{"lcall", 2, 0x9a, _, JumpInterSegment, { Imm16, Abs32|Imm32, 0} C(CallOp)},
+{"lcall", 1, 0xff, 3, Modrm, { Mem, 0, 0} C(ReadMem|CallOp)},
 
 #define JUMP_PC_RELATIVE 0xeb
 {"jmp", 1, 0xeb, _, Jump, { Disp, 0, 0} C(NoMemAcc)},
@@ -682,9 +682,9 @@ static const template i386_optab[] = {
 /* processor control */
 {"fninit", 0, 0xdbe3, _, NoModrm, { 0, 0, 0} C(NoMemAcc)},
 {"finit", 0, 0xdbe3, _, NoModrm, { 0, 0, 0} C(NoMemAcc)},
-{"fldcw", 1, 0xd9, 5, Modrm, { Mem, 0, 0} C(WF32bOp)},
-{"fnstcw", 1, 0xd9, 7, Modrm, { Mem, 0, 0} C(WF32bOp)},
-{"fstcw", 1, 0xd9, 7, Modrm, { Mem, 0, 0} C(WF32bOp)},
+{"fldcw", 1, 0xd9, 5, Modrm, { Mem, 0, 0} C(WF16bOp)},
+{"fnstcw", 1, 0xd9, 7, Modrm, { Mem, 0, 0} C(WF16bOp)},
+{"fstcw", 1, 0xd9, 7, Modrm, { Mem, 0, 0} C(WF16bOp)},
 {"fnstsw", 1, 0xdfe0, _, NoModrm, { Acc, 0, 0} C(NoMemAcc)},
 {"fnstsw", 1, 0xdd, 7, Modrm, { Mem, 0, 0} C(WF32bOp)},
 {"fnstsw", 0, 0xdfe0, _, NoModrm, { 0, 0, 0} C(NoMemAcc)},
