@@ -143,6 +143,7 @@ enum locals_action discard_locals;
 #define UNCHANGE 0
 #define EXPORT 1
 #define HIDE 2
+#define NOTDEF 3
 int nbr_T_export;
 char **T_export;
 struct obstack o_exp_name;
@@ -150,6 +151,8 @@ struct obstack o_exp_tab;
 int default_exp = HIDE;
 int allow_debug;
 int verbose;
+int chkrstrip = 0;
+int setcheckerflag;
 
 /* The name this program was run with. */
 char *program_name;
@@ -176,6 +179,7 @@ struct option long_options[] =
   {"discard-all", 0, 0, 'x'},
   {"discard-locals", 0, 0, 'X'},
   {"verbose", 0, 0, 'v'},
+  {"cstrip", 0, 0, 'c'},
   {0, 0, 0, 0}
 };
 
@@ -188,7 +192,7 @@ void main (int argc, char *argv[])
 
   discard_locals = locals_undef;
 
-  while ((c = getopt_long (argc, argv, "vxX", long_options, &ind)) != EOF) 
+  while ((c = getopt_long (argc, argv, "cvxX", long_options, &ind)) != EOF) 
     {
       switch (c)
 	{
@@ -203,16 +207,20 @@ void main (int argc, char *argv[])
 	case 'v':
 	  verbose = 1;
 	  break;
+	case 'c':
+	  chkrstrip = 1;
+	  break;
 	default:
 	  usage ();
 	}
     }
 
-  if (argc - optind != 2)
+  if ((chkrstrip && argc - optind != 1) || (!chkrstrip && argc - optind != 2))
     usage ();
   
   /* Read the export rules file */
-  read_rules(argv[optind + 1]);
+  if (!chkrstrip)
+    read_rules(argv[optind + 1]);
   
   file_table = (struct file_entry *) xmalloc (sizeof (struct file_entry));
 
@@ -598,6 +606,8 @@ void rewrite_file_symbols (struct file_entry *entry)
 #endif
       read (input_desc, (char *) &hdr, sizeof hdr);
       hdr.a_syms = nsyms * sizeof (struct nlist);
+      if (setcheckerflag)
+        N_SET_FLAGS(hdr, 0x40);
       lseek (input_desc, -(long) sizeof hdr, 1);
       write (input_desc, (char *) &hdr, sizeof hdr);
     }
@@ -623,36 +633,37 @@ void write_file_syms (struct file_entry *entry, struct nlist *newsyms)
 
   for (; p < end; p++)
     {
-      int write=0;
+      int write=1;
 
-      write = 1;
-      if (is_sym_exported(p, p->n_un.n_strx + string_base) == HIDE)
-        p->n_type &= ~N_EXT; 
-# if 0      
-      switch(p->n_type)
-      {
-        case N_EXT | N_TEXT:
-        	if (is_sym_exported(p->n_un.n_strx + string_base) == 1)
-        	  write = 1;
-        	break;
-        case N_UNDF:
-        case N_UNDF | N_EXT:
-        	write = 1;
-        	break;
-        case 0x44:	/* line number */
-        case 0x64:	/* file name */
-        case 0x80:
-        case 0x24:
-        case 0x20:
-        case 0x26:
-        case 0xa0:
-        	if (allow_debug)
-        	  write = 1;
-        	break;
-        default:
-        	write = 0;
-     }
-#endif     
+      if (chkrstrip)
+        {
+          if (p->n_type & N_STAB)
+            {
+              switch(p->n_type & ~N_EXT)
+              {
+                case 0x24:	/* N_FUN */
+                case 0x44:	/* N_SLINE */
+                case 0x64:	/* N_SO */
+                case 0x84:	/* N_SOL */
+                  write = 1;
+                  break;
+                default:
+                  write = 0;
+              }
+            }
+        }
+      else
+        {
+          if (p->n_type == N_EXT && p->n_value == 0 ) /* imported symbol */
+            {
+              if (is_sym_exported(p, p->n_un.n_strx + string_base) != NOTDEF)
+                fprintf(stderr, "warning: %s is not registred as an undefined symbol.\n",
+            			p->n_un.n_strx + string_base);
+            }
+          else
+            if (is_sym_exported(p, p->n_un.n_strx + string_base) == HIDE)
+              p->n_type &= ~N_EXT;
+        }
      if (write == 0)
        nsyms--;
 #if 0
@@ -779,6 +790,7 @@ int rename (char *from, char *to)
    A control line is:
     export sym
     hide sym
+    notdef sym
     end
     default is export
     default is hide
@@ -801,75 +813,89 @@ void read_rules(char *filename)
  obstack_begin(&o_exp_tab, 4096);
  
  while (fgets(line,2048,file) != NULL)
- {
-   /* skipf comment line */
-   if (line[0] == '#')
-     continue;
-   /* parse line */
-   argc=0;
-   len = strlen(line);
-   for (i=0; i < len;)
    {
-     /* skipf blanks */
-     if (line[i] == ' ' || line[i] == '\n')
-     {
-       i++;
+     /* skipf comment line */
+     if (line[0] == '#')
        continue;
+     /* parse line */
+     argc=0;
+     len = strlen(line);
+     for (i=0; i < len;)
+     {
+       /* skipf blanks */
+       if (line[i] == ' ' || line[i] == '\n')
+         {
+           i++;
+           continue;
+         }
+       argv[argc++] = &line[i];
+       /* search the end of the arg */
+       while (line[i] != '\0' && line[i] != ' ' && line[i] != '\n')
+         i++;
+       /* end of the arg */
+       line[i++] = '\0';
      }
-     argv[argc++] = &line[i];
-     /* search the end of the arg */
-     while (line[i] != '\0' && line[i] != ' ' && line[i] != '\n')
-       i++;
-     /* end of the arg */
-     line[i++] = '\0';
-   }
-   if (argc == 2 && strcmp(argv[0],"export") == 0)
-   {
-     obstack_1grow(&o_exp_name, EXPORT);
-     obstack_grow(&o_exp_name, argv[1], strlen(argv[1])+1);
-     ptr = obstack_finish(&o_exp_name);
-     obstack_ptr_grow(&o_exp_tab, ptr + 1);
-     continue;
-   }
-   if (argc == 2 && strcmp(argv[0],"hide") == 0)
-   {
-     obstack_1grow(&o_exp_name, HIDE);
-     obstack_grow(&o_exp_name, argv[1], strlen(argv[1])+1);
-     ptr = obstack_finish(&o_exp_name);
-     obstack_ptr_grow(&o_exp_tab, ptr + 1);
-     continue;
-   }   
-   if (argc == 3 && strcmp(argv[0],"allow") == 0 
-   		 && strcmp(argv[1],"debug") == 0
-   		 && strcmp(argv[2],"symbols")==0)
-   {
-     allow_debug=1;
-     continue;
-   }
-   if (argc == 3 && strcmp(argv[0], "default") == 0
+     if (argc == 2 && strcmp(argv[0], "export") == 0)
+       {
+         obstack_1grow(&o_exp_name, EXPORT);
+         obstack_grow(&o_exp_name, argv[1], strlen(argv[1])+1);
+         ptr = obstack_finish(&o_exp_name);
+         obstack_ptr_grow(&o_exp_tab, ptr + 1);
+         continue;
+       }
+     if (argc == 2 && strcmp(argv[0], "hide") == 0)
+       {
+         obstack_1grow(&o_exp_name, HIDE);
+         obstack_grow(&o_exp_name, argv[1], strlen(argv[1])+1);
+         ptr = obstack_finish(&o_exp_name);
+         obstack_ptr_grow(&o_exp_tab, ptr + 1);
+         continue;
+       }
+     if (argc == 2 && strcmp(argv[0], "notdef") == 0)
+       {
+         obstack_1grow(&o_exp_name, NOTDEF);
+         obstack_grow(&o_exp_name, argv[1], strlen(argv[1])+1);
+         ptr = obstack_finish(&o_exp_name);
+         obstack_ptr_grow(&o_exp_tab, ptr + 1);
+         continue;
+       }
+     if (argc == 3 && strcmp(argv[0], "allow") == 0 
+   		 && strcmp(argv[1], "debug") == 0
+   		 && strcmp(argv[2], "symbols")==0)
+       {
+         allow_debug=1;
+         continue;
+       }
+     if (argc == 2 && strcmp(argv[0], "set") == 0
+    		 && strcmp(argv[1], "checkerflag") == 0)
+       {
+         setcheckerflag = 1;
+         continue;
+       }
+     if (argc == 3 && strcmp(argv[0], "default") == 0
    		 && strcmp(argv[1], "is") == 0)
-   {
-     if (strcmp(argv[2], "hide") == 0)
-     {
-       default_exp = HIDE;
-       continue;
-     }
-     if (strcmp(argv[2], "export") == 0)
-     {
-       default_exp = EXPORT;
-       continue;
-     }
-     if (strcmp(argv[2], "unchange") == 0)
-     {
-       default_exp = UNCHANGE;
-       continue;
-     }
-     error(0,0,"Default mode '%s' is unknown", argv[2]);
+       {
+         if (strcmp(argv[2], "hide") == 0)
+           {
+             default_exp = HIDE;
+             continue;
+           }
+         if (strcmp(argv[2], "export") == 0)
+           {
+             default_exp = EXPORT;
+             continue;
+           }
+         if (strcmp(argv[2], "unchange") == 0)
+           {
+             default_exp = UNCHANGE;
+             continue;
+           }
+         error(0,0,"Default mode '%s' is unknown", argv[2]);
+       }
+     if (argc == 1 && strcmp(argv[0], "end") == 0)
+       break;
+     error(0,0,"Unknown command: %s %s", argv[0], argv[1]);
    }
-   if ( argc == 1 && strcmp(argv[0],"end") == 0)
-     break;
-   error(0,0,"Unknown command: %s %s", argv[0], argv[1]);
- }
  fclose(file);
  obstack_ptr_grow(&o_exp_tab, (void*)0);
  T_export = obstack_finish(&o_exp_tab);
@@ -885,11 +911,25 @@ int is_sym_exported(struct nlist *n, char *sym)
     
  switch(n->n_type & (~N_EXT))
  {
-#if 0 
    case 0:
+#if 0
    	if (n->n_value == 0)
    	  return UNCHANGE;	/* undefined symbols */
-#endif   	  
+#endif
+ 	while(*ptr != (char*)0)
+	{
+	  if (strcmp(sym,*ptr) == 0)
+	  {
+	    res = *((char*)(*ptr - 1));
+	    if (verbose)
+	      fprintf(stderr,"%s is found to %d\n", sym, res);
+	    return res == NOTDEF ? NOTDEF : UNCHANGE;
+	  }
+	  ptr++;
+	}
+	if(verbose)
+	  fprintf(stderr,"%s is not found\n",sym);
+	return UNCHANGE;
    case N_ABS:
    case N_TEXT:
    case N_DATA:
@@ -920,9 +960,9 @@ int is_sym_exported(struct nlist *n, char *sym)
 
 void usage ()
 {
-  fprintf (stderr, "\
-Usage: %s [-xX] [--discard-all] [--discard-locals] [--verbose]\n\
+  fprintf (stderr, "Usage: %s [-xX] [--discard-all] [--discard-locals] [--verbose]\n\
        obj-file rule-file\n", program_name);
+  fprintf (stderr, "or     %s -c | --cstrip obj-file\n", program_name);
   exit (1);
 }
 
